class AlienShip {

  final static int  NOTHING    = 0;
  final static int  HIT_DRONE  = 1;
  final static int  COLLISION  = 2;
  final static int  REBOUNCE   = 3;
  final static int  HIT_DESTROYER = 4;
  final static int  HIT_DRONE_RED = 5;
  final static int  HIT_DESTROYER_RED = 6;

  PShape  _droneShape;
  PShape  _destroyerShape;
  PShape  _destroyerShieldShape;
  PVector _pos;
  PVector _dir;
  float     _height;
  float     _width;
  int     _type; //defines type of ship
  boolean _bounced = false;
  int    _speed = -2; //start speed destroyer

  //Constructor
  AlienShip(int x, int y, float h, int type) {
    _pos = new PVector(x, y); //set position
    _dir = new PVector(0, 0);  //no direction at the beginning
    _height = h;
    if (type == 0) { //if drone
      _width = h*(57/19);
    } 
    else if (type == 1) { //if destroyer
      _width = h*(1.8);  //1.8 = (89/47)
    }
    _type = type; // 0= drone, 1 = destroyer
    _droneShape = loadShape("drone.svg"); //57x19
    _destroyerShieldShape = loadShape("destroyer_shield.svg"); //89x47
    _destroyerShape = loadShape("destroyer.svg"); //89x47
  }

  void update() {
    calcPos(); //get's new Position of the AlienShip
    if (_type == 0) { //if drone
      pushStyle();
      shapeMode(CENTER);
      shape(_droneShape, _pos.x, _pos.y, _width, _height);
      popStyle();
    }
    else if (_type == 1) { //if destroyer
      pushStyle();
      shapeMode(CENTER);
      if (_bounced) { //remove shield
        shape(_destroyerShape, _pos.x, _pos.y, _width, _height);
      } 
      else {
        shape(_destroyerShieldShape, _pos.x, _pos.y, _width, _height);
      }
      popStyle();
    }
  }

  void calcPos() { //update the PVectors for the positioning
    if (_type == 1) {  //if destroyer
      _pos.add(_speed, 0, 0);
    } 
    else {
      _pos.add(_speed -2, 0, 0);
    }
  }

  boolean outOfScreen() {
    if ((_pos.x + _width) < 0) {
      //      println("Alien passed, Huh!");
      return true;
    } 
    else {
      return false;
    }
  }

  int checkHit(float shotX, float shotY, float shotWidth, float shotHeight, int shotType) {
    if (shotX + shotWidth/2 >= _pos.x - _width/2 && shotX - shotWidth/2 <= _pos.x + _width/2  &&//check if shot has reached alien-x
    shotY + shotHeight/2 >= _pos.y - _height/2 && shotY - shotHeight/2 <= _pos.y + _height/2) {
      if (_type == 1 && _bounced == false) { //if AlienShip belongs to  Destroyers and has not bounced yet
        _bounced = true; //sets bounced to true
        return REBOUNCE; //returns 3
      } 
      else {
        if (shotType != 0) { //if red shot
          if (_type == 0) { //if drone
            return HIT_DRONE_RED; //returns 1
          } 
          else {
            return HIT_DESTROYER_RED; //returns 4
          }
        } 
        else {
          if (_type == 0) { //if drone
            return HIT_DRONE; //returns 1
          } 
          else {
            return HIT_DESTROYER; //returns 4
          }
        }
      }
    }
    else {
      return NOTHING; //returns 0
    }
  }

  int checkCollision(float shipX, float shipY, float shipWidth, float shipHeight) {
    if (shipX + shipWidth/2 >= _pos.x - _width/2 && shipX - shipWidth/2 <= _pos.x + _width/2  &&//check if shot has reached alien-x
    shipY + shipHeight/2 >= _pos.y - _height/2 && shipY - shipHeight/2 <= _pos.y + _height/2) {
      return COLLISION; //returns 2
    }
    else {
      return NOTHING;
    }
  }
}

